@@ -525,4 +525,83 @@ mod tests {
             assert_relative_eq!(&actual[..], &desired[..], epsilon = 1e-9);
         }
     }
+
+    /// https://github.com/light-curve/light-curve-feature/issues/29
+    #[test]
+    fn bazin_fit_different_flux_scale() {
+        const MAG_ERR: f64 = 0.01;
+
+        let t = [
+            5369.72858, 5369.77391, 5369.81188, 5369.85266, 5376.65853, 5376.69891, 5376.73714,
+            5376.77595, 5376.8141, 5376.85206, 5377.54863, 5377.59134, 5377.62954, 5377.70322,
+            5377.74667, 5377.78939, 5377.8271, 5377.86528, 5378.54904, 5378.6337, 5378.72268,
+            5378.76098, 5378.79951, 5378.83939, 5378.87711, 5379.51614, 5379.58578, 5379.67183,
+            5379.74434, 5379.782, 5379.81992, 5379.86049, 5380.52762, 5380.56812, 5380.65217,
+            5380.72337, 5380.76161, 5380.79947, 5380.8374, 5381.53714, 5381.57471, 5381.61486,
+            5381.67421, 5381.71252, 5381.75066, 5381.79758, 5381.83571, 5382.52592, 5382.5635,
+            5382.61292, 5382.65083, 5382.69261, 5382.73245, 5382.77025, 5382.82095, 5383.77655,
+            5384.80008, 5385.47067, 5385.50989, 5385.8104, 5385.84797, 5386.47831, 5386.56051,
+            5386.60757, 5386.64396, 5386.74341, 5386.78168, 5386.82469, 5387.50393, 5387.61293,
+            5387.6477, 5387.68716, 5387.72579, 5387.76655, 5387.80776, 5388.46773, 5388.50533,
+            5388.56524, 5388.67765, 5388.76433, 5388.80758, 5388.84645, 5389.49504, 5389.53318,
+            5389.61851, 5389.72375, 5389.78412, 5389.82465, 5390.4695, 5390.52432, 5390.56634,
+            5390.65192, 5390.69816, 5390.74762, 5390.78557, 5390.82325, 5391.5183, 5391.55708,
+            5391.61665, 5391.72592, 5391.8092, 5391.84666, 5392.49444, 5392.53316, 5392.5946,
+            5392.70472, 5392.78668, 5392.82431, 5393.63967, 5393.67939, 5393.71757, 5393.76293,
+            5393.80104, 5395.80807,
+        ];
+        let m = [
+            21.401, 20.299, 20.245, 21.335, 18.103, 18.1, 18.077, 18.088, 18.109, 18.167, 18.132,
+            18.167, 18.144, 18.074, 18.187, 18.124, 18.113, 18.075, 18.191, 18.171, 18.182, 18.161,
+            18.181, 18.098, 18.18, 18.164, 18.191, 18.181, 18.189, 18.197, 18.166, 18.08, 18.205,
+            18.161, 18.257, 18.168, 18.232, 18.264, 18.112, 18.254, 18.126, 18.156, 18.296, 18.142,
+            18.048, 18.233, 18.223, 18.256, 18.223, 18.034, 18.238, 18.243, 18.087, 18.031, 18.32,
+            18.12, 18.279, 18.225, 18.234, 18.175, 18.134, 18.3, 18.257, 18.314, 18.113, 18.333,
+            18.18, 18.259, 18.342, 18.204, 18.304, 18.324, 18.33, 18.25, 18.312, 18.41, 18.388,
+            18.357, 18.428, 18.412, 18.452, 18.319, 18.44, 18.431, 18.465, 18.418, 18.491, 18.294,
+            18.58, 18.402, 18.483, 18.494, 18.531, 18.53, 18.449, 18.498, 18.575, 18.674, 18.548,
+            18.715, 18.562, 18.566, 18.784, 18.642, 18.614, 18.708, 18.637, 18.642, 18.785, 18.825,
+            18.598, 18.763, 18.858, 18.974,
+        ];
+
+        let f0 = [3.63e-20f64, 1.0];
+        let m_models: Vec<_> = f0
+            .iter()
+            .map(|&f0| {
+                let flux: Vec<_> = m.iter().map(|&y| f0 * f64::powf(10.0, -0.4 * y)).collect();
+                let w: Vec<_> = flux
+                    .iter()
+                    .map(|y| (0.4 * f64::ln(10.0) * y * MAG_ERR).powi(-2)) // 1 / sigma^2
+                    .collect();
+
+                let mut ts = TimeSeries::new(&t, &flux, &w);
+                let bazin = BazinFit::new(
+                    McmcCurveFit::new(1_000, None).into(),
+                    LnPrior::none(),
+                    BazinInitsBounds::option_arrays(
+                        [None; 5],
+                        [
+                            None,
+                            Some(f0 * f64::powf(10.0, -0.4 * 22.0)),
+                            None,
+                            None,
+                            None,
+                        ],
+                        [None; 5],
+                    ),
+                );
+                let result = bazin.eval(&mut ts).unwrap();
+
+                let t_model = Array1::linspace(t[0] - 1.0, t[t.len() - 1] + 1.0, 100);
+                let flux_model =
+                    t_model.mapv(|x| BazinFit::model(x, &result[..NPARAMS].try_into().unwrap()));
+                flux_model.mapv(|y| -2.5 * f64::log10(y / f0))
+            })
+            .collect();
+        assert_relative_eq!(
+            m_models[0].as_slice().unwrap(),
+            m_models[1].as_slice().unwrap(),
+            epsilon = 1e-9,
+        );
+    }
 }
